package com.ruoyi.warehouseBusiness.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.warehouseBusiness.domain.TWarehousebillsfeesLogger;
import com.ruoyi.warehouseBusiness.mapper.TWarehousebillsfeesLoggerMapper;
import com.ruoyi.warehouseBusiness.service.ITWarehousebillsfeesLoggerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 仓库费用明细(修改记录)Service业务层处理
 * 
 * @author ruoyi
 * @date 2021-07-05
 */
@Service
public class TWarehousebillsfeesLoggerServiceImpl implements ITWarehousebillsfeesLoggerService
{
    @Autowired
    private TWarehousebillsfeesLoggerMapper tWarehousebillsfeesLoggerMapper;

    /**
     * 查询仓库费用明细(修改记录)
     * 
     * @param fId 仓库费用明细(修改记录)ID
     * @return 仓库费用明细(修改记录)
     */
    @Override
    public TWarehousebillsfeesLogger selectTWarehousebillsfeesLoggerById(Long fId)
    {
        return tWarehousebillsfeesLoggerMapper.selectTWarehousebillsfeesLoggerById(fId);
    }

    /**
     * 查询仓库费用明细(修改记录)列表
     * 
     * @param tWarehousebillsfeesLogger 仓库费用明细(修改记录)
     * @return 仓库费用明细(修改记录)
     */
    @Override
    public List<TWarehousebillsfeesLogger> selectTWarehousebillsfeesLoggerList(TWarehousebillsfeesLogger tWarehousebillsfeesLogger)
    {
        return tWarehousebillsfeesLoggerMapper.selectTWarehousebillsfeesLoggerList(tWarehousebillsfeesLogger);
    }

    /**
     * 新增仓库费用明细(修改记录)
     * 
     * @param tWarehousebillsfeesLogger 仓库费用明细(修改记录)
     * @return 结果
     */
    @Override
    public int insertTWarehousebillsfeesLogger(TWarehousebillsfeesLogger tWarehousebillsfeesLogger)
    {
        tWarehousebillsfeesLogger.setCreateTime(DateUtils.getNowDate());
        return tWarehousebillsfeesLoggerMapper.insertTWarehousebillsfeesLogger(tWarehousebillsfeesLogger);
    }

    /**
     * 修改仓库费用明细(修改记录)
     * 
     * @param tWarehousebillsfeesLogger 仓库费用明细(修改记录)
     * @return 结果
     */
    @Override
    public int updateTWarehousebillsfeesLogger(TWarehousebillsfeesLogger tWarehousebillsfeesLogger)
    {
        tWarehousebillsfeesLogger.setUpdateTime(DateUtils.getNowDate());
        return tWarehousebillsfeesLoggerMapper.updateTWarehousebillsfeesLogger(tWarehousebillsfeesLogger);
    }

    /**
     * 批量删除仓库费用明细(修改记录)
     * 
     * @param fIds 需要删除的仓库费用明细(修改记录)ID
     * @return 结果
     */
    @Override
    public int deleteTWarehousebillsfeesLoggerByIds(Long[] fIds)
    {
        return tWarehousebillsfeesLoggerMapper.deleteTWarehousebillsfeesLoggerByIds(fIds);
    }

    /**
     * 删除仓库费用明细(修改记录)信息
     * 
     * @param fId 仓库费用明细(修改记录)ID
     * @return 结果
     */
    @Override
    public int deleteTWarehousebillsfeesLoggerById(Long fId)
    {
        return tWarehousebillsfeesLoggerMapper.deleteTWarehousebillsfeesLoggerById(fId);
    }
}
