package com.ruoyi.web.controller.warehouse.warehouseBusiness;

import java.util.List;

import com.ruoyi.warehouseBusiness.domain.TWarehousebillsfeesLogger;
import com.ruoyi.warehouseBusiness.service.ITWarehousebillsfeesLoggerService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 仓库费用明细(修改记录)Controller
 * 
 * @author ruoyi
 * @date 2021-07-05
 */
@RestController
@RequestMapping("/warehouse/tWarehousebillsfeesLogger")
public class TWarehousebillsfeesLoggerController extends BaseController
{
    @Autowired
    private ITWarehousebillsfeesLoggerService tWarehousebillsfeesLoggerService;

    /**
     * 查询仓库费用明细(修改记录)列表
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:list')")
    @GetMapping("/list")
    public TableDataInfo list(TWarehousebillsfeesLogger tWarehousebillsfeesLogger)
    {
        startPage();
        List<TWarehousebillsfeesLogger> list = tWarehousebillsfeesLoggerService.selectTWarehousebillsfeesLoggerList(tWarehousebillsfeesLogger);
        return getDataTable(list);
    }

    /**
     * 导出仓库费用明细(修改记录)列表
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:export')")
    @Log(title = "仓库费用明细(修改记录)", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TWarehousebillsfeesLogger tWarehousebillsfeesLogger)
    {
        List<TWarehousebillsfeesLogger> list = tWarehousebillsfeesLoggerService.selectTWarehousebillsfeesLoggerList(tWarehousebillsfeesLogger);
        ExcelUtil<TWarehousebillsfeesLogger> util = new ExcelUtil<TWarehousebillsfeesLogger>(TWarehousebillsfeesLogger.class);
        return util.exportExcel(list, "logger");
    }

    /**
     * 获取仓库费用明细(修改记录)详细信息
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:query')")
    @GetMapping(value = "/{fId}")
    public AjaxResult getInfo(@PathVariable("fId") Long fId)
    {
        return AjaxResult.success(tWarehousebillsfeesLoggerService.selectTWarehousebillsfeesLoggerById(fId));
    }

    /**
     * 新增仓库费用明细(修改记录)
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:add')")
    @Log(title = "仓库费用明细(修改记录)", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TWarehousebillsfeesLogger tWarehousebillsfeesLogger)
    {
        return toAjax(tWarehousebillsfeesLoggerService.insertTWarehousebillsfeesLogger(tWarehousebillsfeesLogger));
    }

    /**
     * 修改仓库费用明细(修改记录)
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:edit')")
    @Log(title = "仓库费用明细(修改记录)", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TWarehousebillsfeesLogger tWarehousebillsfeesLogger)
    {
        return toAjax(tWarehousebillsfeesLoggerService.updateTWarehousebillsfeesLogger(tWarehousebillsfeesLogger));
    }

    /**
     * 删除仓库费用明细(修改记录)
     */
    @PreAuthorize("@ss.hasPermi('warehouse:logger:remove')")
    @Log(title = "仓库费用明细(修改记录)", businessType = BusinessType.DELETE)
	@DeleteMapping("/{fIds}")
    public AjaxResult remove(@PathVariable Long[] fIds)
    {
        return toAjax(tWarehousebillsfeesLoggerService.deleteTWarehousebillsfeesLoggerByIds(fIds));
    }
}
